@@ -315,7 +315,7 @@ gss_get_child_nodes (GnomeScanPlugin *plugin,
 	GList* list = NULL;
 	
 	priv->load = gegl_node_new_child (root,
-					  "operation", "load-buffer",
+					  "operation", "gegl:load-buffer",
 					  "buffer", priv->buffer,
 					  NULL);
 	list = g_list_append (list, priv->load);
@@ -694,7 +694,8 @@ gss_probe_options(GSaneScanner *gss)
 	
 	spec = gss_option_get_param_spec (gss, 0);
 	value = gsane_scanner_option_get_value(gss, spec);
-	n = g_value_get_int (value);
+	n = g_value_get_int(value);
+	g_free(value);
 	
 	gs_debug(" === Device %s (%d options) ===",
 		 gnome_scan_plugin_get_name(GNOME_SCAN_PLUGIN(gss)), n);
@@ -837,6 +838,10 @@ gss_option_get_param_spec (GSaneScanner *gss, SANE_Int n)
 		break;
 	}
 	
+	/* workaround buggy epson driver */
+	if (n == 0)
+		type = G_TYPE_INT;
+	
 	name = g_utf8_strlen(desc->name, 32) < 1 ?
 		g_strdup_printf("option-%i", unnamed++)
 		: g_strdup (desc->name);
